@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 
 import pytest
 
@@ -6,8 +7,8 @@ from six.moves import urllib
 import gnomegmail
 
 base_mail_dict = {
-    'to': "to@example.com",
-    'from': "from@example.com",
+    'to': "to@exämple.com",
+    'from': "from@exämple.com",
 }
 
 
